%{!?lua_version: %global lua_version %{lua: print(string.sub(_VERSION, 5))}}

%global sslcert    %{_sysconfdir}/pki/%{name}/localhost.crt
%global sslkey     %{_sysconfdir}/pki/%{name}/localhost.key

Summary:           Flexible communications server for Jabber/XMPP
Name:              prosody
Version:           0.12.4
Release:    2%{?dist}
License:           MIT
URL:               https://prosody.im/
Source0:           https://prosody.im/downloads/source/%{name}-%{version}.tar.gz
Source1:           https://prosody.im/downloads/source/%{name}-%{version}.tar.gz.asc
Source2:           https://keys.openpgp.org/vks/v1/by-fingerprint/3E52119EF853C59678DBBF6BADED9A77B67AD329
Source3:           prosody.service
Source4:           prosody.logrotate
Source5:           prosody.tmpfilesd
Source6:           prosody.sysusersd
Source7:           prosody-localhost.cfg.lua
Source8:           prosody-example.com.cfg.lua
Patch0:            prosody-0.12.3-config.patch
BuildRequires:     gnupg2
BuildRequires:     gcc
BuildRequires:     make
BuildRequires:     libicu-devel
BuildRequires:     openssl-devel
BuildRequires:     lua
BuildRequires:     lua-devel
BuildRequires:     systemd-rpm-macros
Requires:          %{_bindir}/openssl
Requires(post):    %{_bindir}/openssl
Requires:          lua(abi) = %{lua_version}
Requires:          lua-filesystem
Requires:          lua-expat
Requires:          lua-socket
Requires:          lua-sec
Recommends:        lua-unbound
Recommends:        lua-readline
%{?systemd_requires}
%{?sysusers_requires_compat}

BuildRequires:     lua-filesystem
BuildRequires:     lua-expat
BuildRequires:     lua-socket
BuildRequires:     lua-sec
BuildRequires:     lua-unbound
BuildRequires:     %{_bindir}/openssl
BuildRequires:     %{_sbindir}/ss

%description
Prosody is a flexible communications server for Jabber/XMPP written in Lua.
It aims to be easy to use, and light on resources. For developers it aims
to be easy to extend and give a flexible system on which to rapidly develop
added functionality, or prototype new protocols.

%prep
%setup -q
%patch0 -p1 -b .config

%build
./configure \
  --prefix=%{_prefix} \
  --libdir=%{_libdir} \
  --idn-library=icu \
  --add-cflags="$RPM_OPT_FLAGS" \
  --add-ldflags="$RPM_LD_FLAGS" \
  --no-example-certs
%make_build

%make_build -C tools/migration

%install
mkdir -p %{buildroot}{%{_sysconfdir}/pki,%{_localstatedir}/{lib,log}/%{name}}/
%make_install

%make_install -C tools/migration

install -p -m 0755 tools/ejabberd2prosody.lua %{buildroot}%{_bindir}/ejabberd2prosody
sed -e 's@;../?.lua@;%{_libdir}/%{name}/util/?.lua;%{_libdir}/%{name}/?.lua;@' \
  -i %{buildroot}%{_bindir}/ejabberd2prosody
touch -c -r tools/ejabberd2prosody.lua %{buildroot}%{_bindir}/ejabberd2prosody
install -p -m 0644 tools/erlparse.lua %{buildroot}%{_libdir}/%{name}/util/

mv -f %{buildroot}%{_sysconfdir}/%{name}/certs/ %{buildroot}%{_sysconfdir}/pki/%{name}/
ln -s ../pki/%{name}/ %{buildroot}%{_sysconfdir}/%{name}/certs

install -D -p -m 0644 %{SOURCE3} %{buildroot}%{_unitdir}/%{name}.service
install -D -p -m 0644 %{SOURCE4} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}
install -D -p -m 0644 %{SOURCE5} %{buildroot}%{_tmpfilesdir}/%{name}.conf
install -D -p -m 0644 %{SOURCE6} %{buildroot}%{_sysusersdir}/%{name}.conf
mkdir -p %{buildroot}/run/%{name}/

touch -c -r prosody.cfg.lua.dist.config %{buildroot}%{_sysconfdir}/%{name}/prosody.cfg.lua

install -D -p -m 0644 %{SOURCE7} %{buildroot}%{_sysconfdir}/%{name}/conf.d/localhost.cfg.lua
install -D -p -m 0644 %{SOURCE8} %{buildroot}%{_sysconfdir}/%{name}/conf.d/example.com.cfg.lua

chmod 0755 %{buildroot}%{_libdir}/%{name}/util/*.so

for file in doc/stanza.txt doc/session.txt doc/roster_format.txt; do
  sed -e 's/\r//g' ${file} > ${file}.eol
  touch -c -r ${file} ${file}.eol; mv -f ${file}.eol ${file}
done

%check

%pre
%sysusers_create_compat %{SOURCE6}

%post
%systemd_post %{name}.service

if [ ! -f %{sslkey} ]; then
  umask 077
  %{_bindir}/openssl genrsa 4096 > %{sslkey} 2> /dev/null
  chown root:%{name} %{sslkey}
  chmod 640 %{sslkey}
fi

if [ ! -f %{sslcert} ]; then
  FQDN=`hostname 2> /dev/null`
  if [ "x${FQDN}" = "x" ]; then
    FQDN=localhost.localdomain
  fi

  %{_bindir}/openssl req -new -key %{sslkey} -x509 -sha256 -days 365 -set_serial $RANDOM -out %{sslcert} \
    -subj "/C=--/ST=SomeState/L=SomeCity/O=SomeOrganization/OU=SomeOrganizationalUnit/CN=${FQDN}/emailAddress=root@${FQDN}"
  chmod 0644 %{sslcert}
fi

%preun
%systemd_preun %{name}.service

%postun
%systemd_postun_with_restart %{name}.service

%files
%license COPYING
%doc AUTHORS CHANGES HACKERS README doc/*
%{_bindir}/%{name}
%{_bindir}/%{name}ctl
%{_bindir}/%{name}-migrator
%{_bindir}/ejabberd2prosody
%{_libdir}/%{name}/
%dir %attr(0750,root,%{name}) %{_sysconfdir}/pki/%{name}/
%config(noreplace) %attr(0640,root,%{name}) %{_sysconfdir}/pki/%{name}/*
%dir %attr(0750,root,%{name}) %{_sysconfdir}/%{name}/
%config(noreplace) %attr(0640,root,%{name}) %{_sysconfdir}/%{name}/*.cfg.lua
%dir %attr(0750,root,%{name}) %{_sysconfdir}/%{name}/conf.d/
%config(noreplace) %attr(0640,root,%{name}) %{_sysconfdir}/%{name}/conf.d/*.cfg.lua
%{_sysconfdir}/%{name}/certs
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%{_unitdir}/%{name}.service
%{_sysusersdir}/%{name}.conf
%{_tmpfilesdir}/%{name}.conf
%dir %attr(0755,%{name},%{name}) /run/%{name}/
%dir %attr(0750,%{name},%{name}) %{_localstatedir}/lib/%{name}/
%dir %attr(0750,%{name},%{name}) %{_localstatedir}/log/%{name}/
%{_mandir}/man1/%{name}ctl.1*

%changelog
* Thu Jan 09 2025 bbrucezhang <bbrucezhang@tencent.com> - 0.12.4-2
- Rebuild for icu-74.2

* Wed Aug 28 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.12.4-1
- initial build
